package jfrace;

/**
 *  Interface for all {@link Device Devices} which needs a
 *  parameter dependent configuration. The class name of
 *  an implementation has to fullfill the following the
 *  naming rule: The full class name of the
 *  <code>Device</code> followed by the string
 *  <code>Configurator</code>.
 *
 *  @author Franz-Josef Elmer
 */
public interface Configurator {
    /**
     *  Create and configurate a {@link Device} which will be
     *  attached to the address space.
     *  @param as Address space to which the device will be attached.
     *  @param configResources Configuration details as well as
     *                         address offset and mode mask for the
     *                         address space. Will often be a
     *                         the name of a configuration file.
     *  @param packagePrefix Package prefix from the emulator
     *                       configuration file.
     *  @param args Optional command line arguments
     *  @return <code>true</code> if the device has been successfully
     *          configurated and added to the address space.
     */
    public boolean configurate(AddressSpace as, String configResources,
                               String packagePrefix, String[] args);
}
