package jfrace;

/**
 *  An interface for a terminal.
 *
 *  @author Franz-Josef Elmer
 */
public interface Terminal {
    /** Return the name of the terminal. */
    public String getName();

    /**
     *  Return the device of the terminal. If no <code>Device</code>
     *  return <code>null</code>.
     */
    public Device getDevice();

    /** Return <code>true</code> if there is no character typed. */
    public boolean isEmpty();

    /**
     *  Return a typed character if available. Otherwise
     *  <code>'\0'</code> is returned. Note that an available character
     *  can be read only once.
     *  @see getNextChar
     */
    public char readChar();

    /**
     *  Get the next character typed in. If no character is available
     *  the method is waiting until the user enters a character.
     *  @see readChar
     */
    public char getNextChar();

    /**
     *  Write a character to the terminal.
     */
    public void writeChar(char c);

}
