package jfrace.device;

import jfrace.AddressSpaceEvent;
import jfrace.AddressSpaceListener;
import jfrace.Hardware;

/**
 *  Keyboard of my old ELZET 80 system.
 *
 *  @author Franz-Josef Elmer
 */
public class ELZET80Keyboard extends DummyDevice
                                     implements AddressSpaceListener {
    private CPMEmulator emu;

    public ELZET80Keyboard() {}

//
//  Implemention of the AddressSpaceListener interface.
//

    /**
     *  Catch the <code>CPMEmulator</code> when it is added to the
     *  address space.
     */
    public void hardwareMoved(AddressSpaceEvent event) {
        Hardware hardware = event.getHardware();
        if (event.getType() == AddressSpaceEvent.ADD
                && hardware instanceof CPMEmulator) {
            emu = (CPMEmulator) hardware;
        }
    }

    /** Return 3 as the number of addressable units. */
    public int getNumberOfUnits() {
        return 3;
    }

    /**
     *  Return the byte at the given address.
     *  This method is similar
     *  to <code>getValue</code> but has a better performance.
     *  <br>WARNING: This method should
     *  be used only when the addressable unit is a byte.
     *  @param address memory address.
     *  @return the value of the byte at <code>address</code>.
     *  @see getValue
     */
    public byte getByte(int address) {
        if (emu != null) {
            int function = (address == 0) ? CPMEmulator.CONIN
                                          : CPMEmulator.CONST;
            return emu.processBIOSFunction(function, 0, 0);
        } else {
            return 0;
        }
    }

}
