package jfrace.device;

import jfrace.Device;

import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.event.*;

/**
 *  Panel of horizontally arrange <code>LCDDigit</code>s.
 *
 *  @see jfrace.device.LCDDigit
 *  @author Franz-Josef Elmer
 */
public class LCDPanel extends Frame implements Device {
    private static final int DEFAULT_NUMBER = 5;
    private LCDDigit[] digits;

    /** Create a panel with 5 digits. */
    public LCDPanel() {
        this(DEFAULT_NUMBER);
        addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent we) {
                    we.getWindow().dispose();
                }
            });
    }

    /** Create a panel with a given number of digits. */
    public LCDPanel(int numberOfDigits) {
        super("LCD Panel");
        setLayout(new GridLayout(1, numberOfDigits));
        digits = new LCDDigit[numberOfDigits];
        for (int i = 0; i < numberOfDigits; i++) {
            digits[i] = new LCDDigit();
            add(digits[i]);
        }
        pack();
        show();
    }

//
//  Implementation of the Device interface
//

    /** Reset all digits. */
    public void reset() {
        for (int i = 0; i < digits.length; i++) {
            digits[i].reset();
        }
    }

    /** Return 8. */
    public int getNumberOfBits() {
        return 8;
    }

    /** Return the number of digits. */
    public int getNumberOfUnits() {
        return digits.length;
    }

    /** Nothing to read. Return 0. */
    public int getValue(int address) {
        return 0;
    }

    /**
     *  Show/hide a segment of a digit.
     *  @param address Index of the digit in the panel. The left most
     *                 digit has index 0.
     *  @param value Segment index and visibility flag (bit 4).
     *  @see LCDDigit
     */
    public void setValue(int address, int value) {
        digits[address].setSegment(value & 0xf, (value & 0x10) != 0);
    }

    /** Nothing to read. Return 0. */
    public byte getByte(int address) {
        return 0;
    }

    /**
     *  Show/hide a segment of a digit.
     *  @param address Index of the digit in the panel. The left most
     *                 digit has index 0.
     *  @param value Segment index and visibility flag (bit 4).
     *  @see LCDDigit
     */
    public void setByte(int address, byte value) {
        setValue(address, (int) value);
    }
}
