package jfrace.terminal;

import jfrace.Device;
import jfrace.Terminal;
import jfrace.device.DummyDevice;

/**
 *  Implementation of the console as a terminal.
 *
 *  @author Franz-Josef Elmer
 */
public class Console implements Runnable, Terminal {
    private Thread inputThread;
    private boolean isWaiting;
    private char[] typeAheadBuffer = new char[20];
    private int freePos = 0;
    private int nextPos = 0;
    private Device device = new DummyDevice();

    public Console() {
        inputThread = new Thread(this);
//        inputThread.start();
    }


//
//  Implementation of the Runnable interface.
//

    public void run() {
        Thread t = Thread.currentThread();
        while (t == inputThread) {
            try {
                typeAheadBuffer[freePos++] = (char) System.in.read();
            } catch (Exception e) {
                System.out.println("Console.run " + e);
            }
            freePos %= typeAheadBuffer.length;
            if (isWaiting) {
                synchronized (this) {
                    notify();
                }
            }
        }
    }

//
//  Implementation of the Terminal interface.
//

    /** Return the name of the terminal. */
    public String getName() {
        return "Console";
    }


    /** Return the device of the terminal. */
    public Device getDevice() {
        return device;
    }

    /** Return <code>true</code> if the type-ahead buffer is empty. */
    public boolean isEmpty() {
        return nextPos == freePos;
    }

    /**
     *  Return a character from the type-ahead buffer. Return
     *  <code>'\0'</code> if the buffer is empty.
     */
    public char readChar() {
        if (isEmpty()) {
            return '\0';
        } else {
            char c = typeAheadBuffer[nextPos++];
            nextPos %= typeAheadBuffer.length;
            return c;
        }
    }

    /**
     *  Get the next character typed in.
     */
    public synchronized char getNextChar() {
/*
        if (isEmpty()) {
            try {
                isWaiting = true;
                wait();
            } catch (Exception e) {}
            isWaiting = false;
        }
        char c = typeAheadBuffer[nextPos++];
        nextPos %= typeAheadBuffer.length;
        return c;
*/
        try {
            char c = (char) System.in.read();
            while (c == '\n') {
                c =  (char) System.in.read();
            }
            return c;
        } catch (Exception e) {
            System.out.println("Console: " +e);
            return '\0';
        }
    }

    /**
     *  Send a character to the screen.
     */
    public void writeChar(char c) {
        System.out.print(c);
    }

//////////// Testing //////////

    public static void main(String[] args) {
        try {
            int c = 0;
            while (c != (int) 'Z') {
                c = System.in.read();
                System.out.println("c="+c+" '"+((char) c)+"'");
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
