package jfrace;

import junit.framework.*;

public class UtilTest extends TestCase {
    public UtilTest(String name) {
        super(name);
    }

    public static Test suite() {
        return new TestSuite(UtilTest.class);
    }

    public void testAppendHex() {
        StringBuffer sb = new StringBuffer();
        Util.appendHex(sb, (byte) 0xfe);
        assertEquals("byte appendHex(sb, 0xfe)", new String(sb), "FE");
        Util.appendHex(sb, (byte) 5);
        assertEquals("byte appendHex(sb, 5)", new String(sb), "FE05");
        Util.appendHex(sb, (byte) 0);
        assertEquals("byte appendHex(sb, 0)", new String(sb), "FE0500");

        sb.setLength(0);
        Util.appendHex(sb, 0xfe);
        assertEquals("int appendHex(sb, 0xfe)", new String(sb), "000000FE");
        Util.appendHex(sb, 0x12a3);
        assertEquals("int appendHex(sb, 0x12a3)", new String(sb), "000000FE000012A3");
        Util.appendHex(sb, 0xde0099);
        assertEquals("int appendHex(sb, 0xde0099)", new String(sb),
                     "000000FE000012A300DE0099");
        Util.appendHex(sb, 0xaffe0fee);
        assertEquals("int appendHex(sb, 0xaffe0fee)", new String(sb),
                     "000000FE000012A300DE0099AFFE0FEE");

        long number = 0xabcdef0123456789L;
        sb.setLength(0);
        Util.appendHex(sb, 1, number);
        assertEquals("appendHex(sb, 1, 0xabcdef0123456789L )",
                     new String(sb), "9");
        sb.setLength(0);
        Util.appendHex(sb, 2, number);
        assertEquals("appendHex(sb, 2, 0xabcdef0123456789L )",
                     new String(sb), "89");
        sb.setLength(0);
        Util.appendHex(sb, 12, number);
        assertEquals("appendHex(sb, 12, 0xabcdef0123456789L )",
                     new String(sb), "EF0123456789");
        sb.setLength(0);
        Util.appendHex(sb, 16, number);
        assertEquals("appendHex(sb, 16, 0xabcdef0123456789L )",
                     new String(sb), "ABCDEF0123456789");
        sb.setLength(0);
        Util.appendHex(sb, 16, 0x1234567890abcdefL);
        assertEquals("appendHex(sb, 16, 0x1234567890abcdefL )",
                     new String(sb), "1234567890ABCDEF");
    }

    public void testParseNumber() {
        assertEquals("parseNumber(\"\")", Util.parseNumber(""), 0);
        assertEquals("parseNumber(null)", Util.parseNumber(null), 0);
        assertEquals("parseNumber(\"1234\")", Util.parseNumber("1234"), 1234);
        assertEquals("parseNumber(\"a1234\")", Util.parseNumber("a1234"), 0);
        assertEquals("parseNumber(\" 1234\")", Util.parseNumber(" 1234"), 0);
        assertEquals("parseNumber(\"0b1011\")", Util.parseNumber("0b1011"), 11);
        assertEquals("parseNumber(\"0B1011 \")", Util.parseNumber("0B1011 "), 11);
        assertEquals("parseNumber(\"0b10114\")", Util.parseNumber("0b10114"), 11);
        assertEquals("parseNumber(\"0b4\")", Util.parseNumber("0b4"), 0);
        assertEquals("parseNumber(\"01234\")", Util.parseNumber("01234"), 01234);
        assertEquals("parseNumber(\"0x1A2B34\")", Util.parseNumber("0x1A2B34"), 0x1a2b34);
        assertEquals("parseNumber(\"0X1a23b4\")", Util.parseNumber("0X1a23b4"), 0x1a23b4);
    }

    public void testReadBinaryData() {
        byte[] data = Util.readBinaryData("testingResources/img1.gif");
        assertEquals("length", data.length, 30990);
        assertEquals("1. byte", data[0] & 0xff, 0x47);
        assertEquals("last byte", data[data.length - 1] & 0xff, 0x3b);

        data = Util.readBinaryData("testingResources/test1.hex");
        int[][] expectation = {
            {0xC3, 0x7E, 0xE2, 0xC3, 0xA6, 0xE2, 0xC3, 0x33,
             0xE2, 0xC3, 0x38, 0xE2, 0xC3, 0x3D, 0xE2, 0xC3,
             0x42, 0xE2, 0xC3, 0x47, 0xE2, 0xC3, 0x4C, 0xE2,
             0xC3, 0x51, 0xE2, 0xC3, 0x56, 0xE2, 0xC3, 0x5B},
            {0x00, 0xE2, 0x03, 0x00, 0xC4, 0xE2, 0x01, 0xD4,
             0xE2, 0x02, 0xE4, 0xE2},
            {0x4D, 0xE5},
            };
        int[] offsets = {0xE200, 0xE554, 0xFFFE};
        for (int i = 0; i < offsets.length; i++) {
            for (int j = 0; j < expectation[i].length; j++) {
                assertEquals("[" + i + "][" + j + "]",
                             expectation[i][j], data[offsets[i] + j] & 0xff);
            }
        }
    }
}
